@@ -2,8 +2,10 @@ use strict;
 use warnings;
 package App::Nopaste::Service::Debian;
 # ABSTRACT: Service provider for Debian - http://paste.debian.net/
-our $VERSION = '1.004';
-use base 'App::Nopaste::Service';
+
+our $VERSION = '1.007';
+
+use parent 'App::Nopaste::Service';
 
 my $languages = {
     "text" => "-1",
@@ -288,7 +290,7 @@ App::Nopaste::Service::Debian - Service provider for Debian - http://paste.debia
 
 =head1 VERSION
 
-version 1.004
+version 1.007
 
 =for stopwords Niebur
 
@@ -296,6 +298,11 @@ version 1.004
 
 Ryan Niebur, C<< <ryanryan52@gmail.com> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
