@@ -2,13 +2,15 @@ use strict;
 use warnings;
 package App::Nopaste::Service::Gist;
 # ABSTRACT: Service provider for GitHub gist - http://gist.github.com/
-our $VERSION = '1.004';
-use base 'App::Nopaste::Service';
 
-use File::Basename ();
+our $VERSION = '1.007';
+
+use parent 'App::Nopaste::Service';
+
 use JSON::MaybeXS;
 use Module::Runtime 'use_module';
-use namespace::clean;
+use Path::Tiny;
+use namespace::clean 0.19;
 
 sub available         { 1 }
 sub forbid_in_default { 0 }
@@ -28,7 +30,7 @@ sub run {
     };
 
     my $filename = defined $arg{filename}
-                 ? File::Basename::basename($arg{filename})
+                 ? path($arg{filename})->basename
                  : 'nopaste';
 
     $content->{files} = {
@@ -75,12 +77,26 @@ sub _get_auth {
             password => $ENV{GITHUB_PASSWORD},
         );
     }
+    else {
+        # this is also done by the fallback mechanism in Config::Identity::GitHub.
+        my $github_config = path('~', '.github');
+        if (-f $github_config) {
+            my $content = $github_config->slurp_utf8;
+            my ($username) = $content =~ m/\blogin (.+)(?:$|#)/m;
+            my ($password) = $content =~ m/\bpassword (.+)(?:$|#)/m;
+            return (
+                username => $username,
+                password => $password,
+            ) if $username and $password;
+        }
+    }
 
     die join("\n",
         "Export GITHUB_OAUTH_TOKEN first. For example:",
         "    perl -MApp::Nopaste::Service::Gist -e 'App::Nopaste::Service::Gist->create_token'",
         "",
         "OR you can export GITHUB_USER and GITHUB_PASSWORD.",
+        "OR you can set 'login' and 'password' in ~/.github.",
     ) . "\n";
 }
 
@@ -155,9 +171,9 @@ App::Nopaste::Service::Gist - Service provider for GitHub gist - http://gist.git
 
 =head1 VERSION
 
-version 1.004
+version 1.007
 
-=for stopwords SIGNES gists oauth
+=for stopwords SIGNES gists oauth plaintext
 
 =head1 GitHub Authorization
 
@@ -171,20 +187,30 @@ or you can use this module to do the same:
 
     perl -MApp::Nopaste::Service::Gist -e 'App::Nopaste::Service::Gist->create_token'
 
-This will grant gist rights to the L<App::Nopaste>, don't worry you can revoke
+This will grant gist rights to the L<App::Nopaste>. Don't worry, you can revoke
 access rights anytime from the GitHub profile settings. Search for C<token> in
-response and export it as C<GITHUB_OAUTH_TOKEN> environment variable.
+response and export it as the C<GITHUB_OAUTH_TOKEN> environment variable.
 
 Alternatively, you can export the C<GITHUB_USER> and C<GITHUB_PASSWORD>
 environment variables, just like for the
 L<gist|https://github.com/defunkt/gist> utility.
 
+You can also simply store your credentials in plaintext in F<~/.github> as in:
+
+    login bob
+    password ilikeducks
+
 That's it!
 
 =head1 AUTHOR
 
 Ricardo SIGNES, C<< <rjbs@cpan.org> >>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Shawn M Moore, <sartak@gmail.com>
