@@ -2,8 +2,10 @@ use strict;
 use warnings;
 package App::Nopaste::Service::Pastie;
 # ABSTRACT: Service provider for Pastie - pastie.org
-our $VERSION = '1.004';
-use base 'App::Nopaste::Service';
+
+our $VERSION = '1.007';
+
+use parent 'App::Nopaste::Service';
 
 my %languages = (
     "bash" => "13",
@@ -107,7 +109,12 @@ App::Nopaste::Service::Pastie - Service provider for Pastie - pastie.org
 
 =head1 VERSION
 
-version 1.004
+version 1.007
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=App-Nopaste>
+(or L<bug-App-Nopaste@rt.cpan.org|mailto:bug-App-Nopaste@rt.cpan.org>).
 
 =head1 AUTHOR
 
